charDecoder

package
v1.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 2, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package charDecoder provides a pass-through decoder for character streams.

It is used for transport modes where incoming data is already plain text and should be forwarded unchanged.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

New creates a character stream decoder.

The returned decoder forwards input bytes as-is. The LUT and endianness fields are stored for API consistency with other decoders.

Types

This section is empty.

Jump to