trice

package
v0.8.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2020 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package trice provides subcommands ScLog and ScReceive It provides optional decryption and activates receiver package, which in turn calls emit.Trice on every received trice.

Index

Constants

This section is empty.

Variables

var (
	// Password is the key one needs to derypt trice logs if enncrypted
	Password string

	// ShowPassword, if set, allows to see the encryption passphrase
	ShowPassword bool
)

local config values

Functions

func DoReceive

func DoReceive() error

DoReceive connects to COM port and displays traces

func NewConnection added in v0.8.3

func NewConnection(sv string) error

NewConnection starts a display server sy if sv is not empty, otherwise it assumes a running display server It connects then to the running display server.

func ScLog

func ScLog() error

ScLog is the subcommand log and connects to COM port and displays traces

func ScReceive

func ScReceive(sv string) error

ScReceive is the subcommand remoteDisplay and acts as client connecting to the displayServer

Types

This section is empty.

Jump to