Documentation
¶
Overview ¶
Package cipher provides XTEA-based helper functions for encrypting and decrypting Trice binary payload blocks.
The package uses a process-global setup configured by Password and SetUp.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Password is the key one needs to decrypt trice logs if encrypted Password string // ShowKey if set, allows to see the encryption passphrase ShowKey bool )
Functions ¶
func Decrypt ¶ added in v0.24.1
Decrypt converts src into dst and returns count of converted bytes. Only multiple of 8 are convertable, so last 0-7 bytes are not convertable and c is a multiple of 8. The smaller byte slice limits the conversion.
func Decrypt8 ¶
Decrypt8 translates an encryption protected byte slice back in a slice of length 8.
The input must be exactly 8 bytes; otherwise the function logs an info message.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.