Documentation
¶
Overview ¶
Package id list is responsible for id list managing
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
Types ¶
type Item ¶
type Item struct {
ID int `json:"id"` // identifier
FmtType string `json:"fmtType"` // format type (bitsize and number of fmt string parameters)
FmtStrg string `json:"fmtStrg"` // format string
Created int32 `json:"created"` // utc unix time of creation
Removed int32 `json:"removed"` // utc unix time of disappearing in processed src directory
}
Item is the basic element
type ListT ¶ added in v0.8.2
type ListT []Item
List is a slice type containing the ID list
func (*ListT) FileWatcher ¶ added in v0.8.3
func (p *ListT) FileWatcher()
ListFileWatcher checks id list file for changes taken from https://medium.com/@skdomino/watch-this-file-watching-in-go-5b5a247cf71f
Click to show internal directories.
Click to hide internal directories.