Documentation
¶
Overview ¶
Package trice provides subcommands ScLog and ScReceive It provides optional decryption and activates receiver package, which in turn calls emit.Trice on every received trice.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Password is the key one needs to derypt trice logs if enncrypted Password string // ShowPassword, if set, allows to see the encryption passphrase ShowPassword bool )
local config values
Functions ¶
func NewConnection ¶ added in v0.8.3
NewConnection starts a display server sy if sv is not empty, otherwise it assumes a running display server It connects then to the running display server.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.